@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Run::Role::Runner;
 
-our $VERSION = '0.039';
+our $VERSION = '0.040';
 
 use Moose::Role;
 use namespace::autoclean;
@@ -24,33 +24,9 @@ has censor_commands => (
     default => 0,
 );
 
-has run => (
+has [ qw(run run_if_trial run_no_trial run_if_release run_no_release) ] => (
     is => 'ro',
-    isa  => 'ArrayRef',
-    default => sub { [] },
-);
-
-has run_if_trial => (
-    is => 'ro',
-    isa  => 'ArrayRef',
-    default => sub { [] },
-);
-
-has run_no_trial => (
-    is => 'ro',
-    isa  => 'ArrayRef',
-    default => sub { [] },
-);
-
-has run_if_release => (
-    is => 'ro',
-    isa  => 'ArrayRef',
-    default => sub { [] },
-);
-
-has run_no_release => (
-    is => 'ro',
-    isa  => 'ArrayRef',
+    isa  => 'ArrayRef[Str]',
     default => sub { [] },
 );
 
@@ -78,7 +54,7 @@ around dump_config => sub
     my $config = $self->$orig;
 
     $config->{+__PACKAGE__} = {
-        (map { $_ => $self->$_ } qw(fatal_errors quiet)),
+        (map { $_ => $self->$_ ? 1 : 0 } qw(fatal_errors quiet)),
         map {
             @{ $self->$_ }
                 # look for user:password URIs
@@ -182,22 +158,26 @@ sub _run_cmd {
     require IPC::Open3;  # core
 
     my $command = $self->build_formatter($params)->format($run_cmd);
-    $self->${ $self->quiet ? \'log_debug' : \'log' }("executing: $command");
+    $self->${ $self->quiet ? \'log_debug' : \'log' }([ 'executing: %s', $command ]);
 
     # autoflush STDOUT so we can see command output right away
     local $| = 1;
-    # combine stdout and stderr for ease of proxying through the logger
+    # combine STDOUT and STDERR for ease of proxying through the logger
     my $pid = IPC::Open3::open3(my ($in, $out), undef, $command);
-    while(defined(my $line = <$out>)){
-        chomp($line); # logger appends its own newline
-        $self->${ $self->quiet ? \'log_debug' : \'log' }($line);
-    }
+    chomp(my @lines = <$out>); # logger appends its own newline
+    $self->${ $self->quiet ? \'log_debug' : \'log' }($_) for @lines;
+
     # zombie repellent
     waitpid($pid, 0);
 
     if (my $status = ($? >> 8)) {
+        if ($self->fatal_errors and $self->quiet and  $self->zilla->logger->get_debug) {
+            $self->log([ 'executed: %s', $command ]) ;
+            $self->log($_) for @lines;
+        }
+
         $self->${ $self->fatal_errors ? \'log_fatal' : $self->quiet ? \'log_debug' : \'log'}
-            ("command exited with status $status ($?)");
+            ([ 'command exited with status %s (%s)', $status, $? ]);
     }
     else {
         $self->log_debug('command executed successfully');
@@ -213,7 +193,7 @@ sub _eval_cmd {
     }
 
     $code = $self->build_formatter($params)->format($code);
-    $self->${ $self->quiet ? \'log_debug' : \'log' }("evaluating: $code");
+    $self->${ $self->quiet ? \'log_debug' : \'log' }([ 'evaluating: %s', $code ]);
 
     my $sub = __eval_wrapper($code);
     $sub->($self);
@@ -221,7 +201,7 @@ sub _eval_cmd {
 
     if (defined $error and $error ne '') {
         $self->${ $self->fatal_errors ? \'log_fatal' : $self->quiet ? \'log_debug' : \'log'}
-            ('evaluation died: ' . $error);
+            ([ 'evaluation died: %s', $error ]);
     }
 }
 
